#include "yeti-oneline.h"

void printOneLineSpectrum(std::ostream & os,
			  const MssmSoftsusy & m,
			  std::string model, 
			  const DoubleVector & pars, 
			  int sgnMu, double tanb, 
			  double qMax, 
			  int numPoints, double mb, 
			  double mtau, double mgut, 
			  bool altEwsb) 
{
  os.setf(ios::fixed | ios::showpoint);
  os.precision(4);

  // Cols 1-6: Input parameters
  // 1: tan beta
  // 2: sign mu
  os << tanb << ' ' << sgnMu << ' ';
  if (model=="sugra") {
    // 3: m0 
    // 4: m12 
    // 5: A0 
    // 6: ---
    os << pars.display(1) << ' ' << pars.display(2) << ' ' 
       << pars.display(3) << ' ' << "x ";
  } else if (model=="gmsb") {
    // 3: lambda 
    // 4: M_mess 
    // 5: N5 
    // 6: cgrav
    os << pars.display(3) << ' ' << pars.display(2) << ' ' 
       << pars.display(1) << ' ' << pars.display(4) << ' ';
  } else if (model=="amsb") {
    // 3: m3/2  
    // 4: m0  
    // 5: --- 
    // 6: ---
    os << pars.display(1) << ' ' << pars.display(2) 
       << "x x ";
  } else {
    cerr << "\nprintOneLineSpectrum() can't recognize model.\n";
    return;
  }

  if (m.displayProblem().test()) {
    for (int i=0; i<34; ++i)
      os << "x ";
    os << '\n';
    return;
  }
  
  sPhysical s(m.displayPhys());

  //  cols 7-11 MW and Higgs
  //  7: MW
  //  8: h0
  //  9: H0
  // 10: A0
  // 11: H+-
  os << m.displayMw() << ' ' 
     << s.mhiggs(1) << ' ' << s.mhiggs(3) << ' ' 
     << s.mhiggs(2) << ' ' << s.mhiggs(4) << ' ';

  // cols 12-18 neutralinos, charginos, gluino
  // 12: neut(1)
  // 13: neut(2)
  // 14: neut(3)
  // 15: neut(4)
  // 16: char(1)
  // 17: char(2)
  // 18: gluino
  os << s.mneut(1) << ' ' << s.mneut(2) << ' ' 
     << s.mneut(3) << ' ' << s.mneut(4) << ' ' 
     << s.mch(1)   << ' ' << s.mch(2)   << ' '
     << s.mGluino  << ' ';

  // cols 19-39 Sleptons (in PDG order)
  // 19: dL
  // 20: uL
  // 21: sL
  // 22: cL
  // 23: b1
  // 24: t1
  os << s.md(1, 1) << ' ' << s.mu(1, 1) << ' '
     << s.md(1, 2) << ' ' << s.mu(1, 2) << ' '
     << minimum(s.md(1, 3), s.md(2, 3)) << ' '
     << minimum(s.mu(1, 3), s.mu(2, 3)) << ' ';

  // 25: eL
  // 26: nu_eL
  // 27: muL
  // 28: nu_muL
  // 29: tau1
  // 30: nu_tauL
  os << s.me(1, 1) << ' ' << s.msnu(1) << ' '
     << s.me(1, 2) << ' ' << s.msnu(2) << ' '
     << minimum(s.me(1, 3), s.me(2, 3)) << ' '
     << s.msnu(3) << ' ';

  // 31: dR
  // 32: uR
  // 33: sR
  // 34: cR
  // 35: b2
  // 36: t2
  os << s.md(2, 1) << ' ' << s.mu(2, 1) << ' '
     << s.md(2, 2) << ' ' << s.mu(2, 2) << ' '
     << maximum(s.md(1, 3), s.md(2, 3)) << ' '
     << maximum(s.mu(1, 3), s.mu(2, 3)) << ' ';

  // 37: eR
  // 38: muR
  // 39: tau2
  os << s.me(2, 1) << ' '
     << s.me(2, 2) << ' '
     << maximum(s.me(1, 3), s.me(2, 3)) << ' ';
  
  // 40: Gravitino
  const double underflow = 1.0e-120;
  if (fabs(m.displayGravitino()) > underflow)
    os << m.displayGravitino() << '\n';
  else
    os << "x\n";
}
